@@ -2,6 +2,8 @@ package Ukigumo::Server;
 use strict;
 use warnings;
 use 5.010001;
+use version; our $VERSION = version->declare('v1.0.0');
+
 use parent qw(Amon2);
 use Carp;
 use DBI;
@@ -12,8 +14,6 @@ use Ukigumo::Server::DB;
 
 __PACKAGE__->load_plugins(qw(ShareDir));
 
-our $VERSION = '0.01';
-
 sub config {
     my ($c, $conf) = @_;
     state $config = $conf || do {
@@ -121,6 +121,10 @@ Or you can use git repo instead of C<< cpanm Ukigumo::Server >> for launching L<
     # Then, run the http server!
     % carton exec perl local/bin/ukigumo-server
 
+=head1 SEE ALSO
+
+L<ukigumo-server>
+
 =head1 LICENSE
 
 Copyright (C) tokuhirom.
